@@ -10,8 +10,14 @@ use base qw/DBIx::Class::Schema/;
 our $VERSION = 0.01;
 
 __PACKAGE__->load_namespaces(
-    result_namespace => ['Core', 'Virtual'],
-    resultset_namespace => 'Virtual',
+    result_namespace => ['Test', 'Virtual', 'Core::Result'],
+    resultset_namespace => ['Test', 'Virtual', 'Core::Result'],
 );
 
+# ---
+# Put your own code below this comment
+# ---
+
+# ---
+
 1;
\ No newline at end of file
